//
//  RendererViewController.m
//  uPnp2
//
//  Created by rk on 20/01/11.
//  Copyright 2011 Interchart. All rights reserved.
//

#import "RendererViewController.h"
#import "DefaultAvRenderer.h"



@implementation RendererViewController


- (id)init {
	self = [super initWithNibName:@"RendererView" bundle:nil];
	return self;
}

-(id)initWithRenderer:(UpnpAvRenderer*)theRenderer {
	self =	[self init];
	renderer = theRenderer;
	[self updateMuteAndVolume];
	return self;
}

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil {
	self = [self init];
    return self;
}


#pragma mark -

-(void)updateMuteAndVolume {
	[renderer.rendererService asynchGetMute:self];
	[renderer.rendererService asynchGetVolume:self];
}

#pragma mark -
#pragma mark Actions

-(IBAction) getMuteButtonPressed:(id)sender {
	NSLog(@"%@: getMuteButtonPressed", self);
	[self updateMuteAndVolume];
}

-(IBAction) muteSwitchTouchup:(id)sender {
	NSLog(@"%@: muteSwitchTouchup", self);
	[renderer.rendererService asynchSetMute:muteSwitch.on :self];
}

-(IBAction)volumeSliderValueChanged:(id)sender {
	float fValue = volumeSlider.value;
	int value = (int)fValue;
	volumeLabel.text = [NSString stringWithFormat:@"%d", value];
	[renderer.rendererService asynchSetVolume:value :self];
}

-(IBAction)playButtonPressed:(id)sender {
	NSLog(@"%@: playButtonPressed", self);
    UpnpAvRenderer *defaultRenderer = [DefaultAvRenderer singletonInstance];
    UpnpAvTransportService *transportService = [defaultRenderer transportService];
    [transportService asynchPlay:1 :nil];    
}

-(IBAction)pauseButtonPressed:(id)sender {
	NSLog(@"%@: pauseButtonPressed", self);
    UpnpAvRenderer *defaultRenderer = [DefaultAvRenderer singletonInstance];
    UpnpAvTransportService *transportService = [defaultRenderer transportService];
    [transportService asynchPause:nil];    
}


#pragma mark -

#pragma mark AsynchUpnpCommandDelegate

- (void)handleAsynchUpnpCommandResult:(GDataXMLDocument *)parsedResult {
	NSLog(@"%@: handleAsynchUpnpCommandResult: parsedResult:%@", self, parsedResult);
	if (parsedResult) {
		if ([UpnpAvRenderingControlService isGetMuteResponse:parsedResult]) {
			[muteSwitch 
			 setOn:[UpnpAvRenderingControlService getMuteResponseValue:parsedResult]
			 animated:true];
		}
		if ([UpnpAvRenderingControlService isGetVolumeResponse:parsedResult]) {
			int iCurrentVolume = [UpnpAvRenderingControlService getVolumeResponseValue:parsedResult];
			float fCurrentVolume = (float)iCurrentVolume;
			volumeSlider.value = fCurrentVolume;
			volumeLabel.text = [NSString stringWithFormat:@"%d", iCurrentVolume];
		}
	}
}
/*
 // Implement viewDidLoad to do additional setup after loading the view, typically from a nib.
 - (void)viewDidLoad {
 [super viewDidLoad];
 }
 */


- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation {
    // Overriden to allow any orientation.
    return YES;
}


- (void)didReceiveMemoryWarning {
    // Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
    
    // Release any cached data, images, etc. that aren't in use.
}


- (void)viewDidUnload {
    [super viewDidUnload];
    // Release any retained subviews of the main view.
    // e.g. self.myOutlet = nil;
}


- (void)dealloc {
    [super dealloc];
}


@end
